/**
	$Id$

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.overview;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.ItemResultIterator;
import net.sf.basedb.core.Role;
import net.sf.basedb.core.User;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.extensions.ChildNodeLoaderAction;
import net.sf.basedb.util.overview.loader.BasicItemNodeLoader;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.node.NameableNameGenerator;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation that load the role membership of a user
	as property nodes. It can't be a root node or a forward/reverse-loading node.
	We extend from the {@link BasicItemNodeLoader} class to be able to take
	advantage of already implemented functionality in the BASE core.
	
	@author Nicklas
	@since 1.5
*/
public class RoleNodeLoader
	extends BasicItemNodeLoader<Role>
	implements ChildNodeLoaderAction
{

	public RoleNodeLoader()
	{
		super(Item.ROLE, DENY_ROOT_NODE, 
				new NameableNameGenerator<Role>("role", "Role"));
	}
	
	/*
		From the NodeLoader interface
		------------------------------
	*/
	@Override
	public Node createPropertyNode(DbControl dc, OverviewContext context, Node parentNode)
	{
		NodeFactory<Role> nf = getNodeFactory(dc, context);
		Node folderNode = null;

		// We know that the parent item is a User since that was
		// checked by the RoleNodeLoaderFactory
		User user = (User)parentNode.getItem(dc);
		
		// Query the database for all roles that the user is a member of
		ItemQuery<Role> query = context.initQuery(user.getRoles(), "name");
		ItemResultIterator<Role> it = query.iterate(dc);
		while (it.hasNext())
		{
			// Create a folder node when needed
			if (folderNode == null)
			{
				folderNode = new Node("roles", "Roles", parentNode, ChildNodeDirection.PROPERTY);
			}
			Role role = it.next();
			// Use the superclass functionality to create the role node
			// It will take care of validation options and more automatically
			createItemNode(nf, role, role, false, folderNode, ChildNodeDirection.PROPERTY);
		}
		// Final validation is also taken care of automatically by the superclass
		postValidateFolder(nf, folderNode, parentNode, false);
		return folderNode;
	}
	// -----------------------------------

	@Override
	public void createChildNodes(DbControl dc, OverviewContext context, Node parentNode) 
	{
		createPropertyNode(dc, context, parentNode);
	}
	
}
