/*
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of the Example Code Package for BASE.
	Available at http://baseplugins.thep.lu.se/
	BASE main site: http://base.thep.lu.se/
	
	This is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	The software is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.examples.extensions.overview;

import net.sf.basedb.core.User;
import net.sf.basedb.util.extensions.ActionFactory;
import net.sf.basedb.util.extensions.ClientContext;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.extensions.ChildNodeLoaderAction;

/**
	Example action factory that create actions that create a folder node
	containing the role membership for a user. The parent node must
	be a node that contain a {@link User} item.

	@author nicklas
	@since 1.5
*/
public class RoleNodeLoaderFactory
	implements ActionFactory<ChildNodeLoaderAction>
{

	/**
	 	A public, no-argument constructor is required
	*/
	public RoleNodeLoaderFactory()
	{}
   
	/**
		Return true enable the extension, false to disable it. This extension is enabled
		if the parent node represents a {@link User} item. The parent node is passed
		as the current item in the client context ({@link ClientContext#getCurrentItem()}).
	*/
	@Override
	public boolean prepareContext(InvokationContext<? super ChildNodeLoaderAction> context) 
	{
		Node parentNode = (Node)context.getClientContext().getCurrentItem();
		if (parentNode != null)
		{
			if (parentNode.getItem() instanceof User)
			{
				return true;
			}
		}
		return false;
	}

	/**
		Create the {@link RoleNodeLoader} action.
	*/
	@Override
	public ChildNodeLoaderAction[] getActions(InvokationContext<? super ChildNodeLoaderAction> context) 
	{
		return new ChildNodeLoaderAction[] { new RoleNodeLoader() };
	}
}
